dialect

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2021 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package dialect contains the Dialect definition and utilities to encode and decode dialects.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DecEncoder

type DecEncoder struct {
	MessageDEs map[uint32]*msg.DecEncoder
}

DecEncoder is an object that allows to decode and encode a Dialect.

func NewDecEncoder

func NewDecEncoder(d *Dialect) (*DecEncoder, error)

NewDecEncoder allocates a DecEncoder.

type Dialect

type Dialect struct {
	// Version is the dialect version.
	Version int

	// Messages contains the messages of the dialect.
	Messages []msg.Message
}

Dialect is a Mavlink dialect.

Jump to